@@ -263,14 +263,14 @@ sub array_unique {
         my $id = $diff->($_);
         next if not exists $tmp{$id} ;
         if($tmp{$id}>1){
-            $self->debug("$info array_unique id duplicate: $id($tmp{$id})") if defined $info;
+            $self->debug("$info array_unique id duplicate: [$id]($tmp{$id})") if defined $info;
             $i++;
             next;
         }
         push @result,$_;
         $info{$id} = $_ if wantarray;
     }
-    $self->debug("$info array_unique id duplicate count: $i") if defined $info and $i >0;
+    $self->debug("$info array_unique id duplicate total count: $i") if defined $info and $i >0;
     return wantarray?(\@result,\%info):\@result;
 }
 sub die{
